@@ -1,11 +1,15 @@
 #!/usr/bin/env python3
+from __future__ import annotations
 import os
 from pathlib import Path
-from typing import Dict, Iterator
+from typing import Iterator
 
 def is_system_root(directory: Path):
     return directory == directory.parent
 
+def is_home_dir(directory: Path):
+    return directory.resolve() == Path.home().resolve()
+
 def yield_parents(directory: Path, max_depth=None) -> Iterator[Path]:
     """generator returning the the current directory and ancestors one after another"""
     max_depth = 999 if max_depth is None else max_depth
@@ -48,7 +52,8 @@ def parse_config(project_root, global_conf_paths=['${HOME}/.rmx.config', '${HOME
     2. $HOME/.rmx.config
     3. $HOME/.config/rmx
     """
-    import json
+    import pyjson5 as json
+
     from os.path import expandvars, isfile
     from rmx import logger
 
@@ -119,6 +124,7 @@ def find_project_root():
                 'Setting project root to current directory')
 
     assert not is_system_root(current_dir), "project root detected is the system root '/' you never want to rsync your entire disk."
+    assert not is_home_dir(current_dir), "project root detected is home directory. You never want to rsync the entire home directory to a remote machine."
     return current_dir
 
 
@@ -167,7 +173,7 @@ def defreeze_dict(frozen_dict: frozenset):
 
 
 
-def replace_rmx_envvars(env: Dict):
+def replace_rmx_envvars(env: dict):
     import re
     # Replace RMX_* envvars: (${RMX_CODE_DIR}, ${RMX_OUTPUT_DIR}, ${RMX_MOUNT_DIR})
     # This cannot happen automatically on remote server side, since we set these envvars exactly at the same time as other envvars.
@@ -175,7 +181,7 @@ def replace_rmx_envvars(env: Dict):
     for target_key in rmx_envvars:
         # Match "${target_key}" or "$target_key"
         regex = r'{}'.format('(\$\{' + target_key + '\}' + f'|\$' + target_key + ')')
-        env = {key: re.sub(regex, env[target_key], str(val)) for key, val in env.items()}
+        env = {key: re.sub(regex, str(env[target_key]), str(val)) for key, val in env.items()}
     return env
 
 
@@ -185,7 +191,7 @@ class LaunchLogManager:
         self.path = path
 
     def _refresh(self):
-        import json
+        import pyjson5 as json
         from datetime import datetime
         # Read entries from the top (oldest) to bottom (newest)
         with open(self.path, 'r') as f:
